@@ -1,5 +1,15 @@
 from __future__ import unicode_literals
 from lib2to3.fixer_base import BaseFix
+from .utils import node_text
+
+
+def get_previous_node(node):
+    """
+    Return the node before this node.
+    """
+    if node.prev_sibling:
+        return node.prev_sibling
+    return get_previous_node(node.parent)
 
 
 class FixWhitespaceBeforeInlineComment(BaseFix):
@@ -12,12 +22,23 @@ class FixWhitespaceBeforeInlineComment(BaseFix):
     '''
 
     def match(self, node):
-        if (node.prefix.count("#") and
-            not node.prefix.lstrip(" \t").startswith("\n")):
-            # If the node starts with a comment and not a newline, then it is
-            # an inline comment.
-            return True
-        return False
+        # An inline comment must contain with a #
+        if not node.prefix.count("#"):
+            return False
+
+        # If the node's prefix starts with a newline, then this is not an
+        # inline comment because there is not code before this.
+        if node.prefix.lstrip(" \t").startswith("\n"):
+            return False
+
+        # If the previous node ended in a newline, then this node is
+        # starting the line so it is not an inline comment.
+        prev_node = get_previous_node(node)
+        prev_node_text = node_text(prev_node)
+        if prev_node_text.endswith('\n'):
+            return False
+
+        return True
 
     def transform(self, node, results):
         position = node.prefix.find("#")
